==> prismstudio-0.0.0.10-py3-none-any.whl: prism/_prismcomponent/prismcomponent.py <==
from abc import ABC, abstractmethod
import copy
from functools import wraps
import numbers
import math
import requests
import uuid

import pandas as pd

from .._prismcomponent.abstract_prismcomponent import _AbstractPrismComponent
from .._common.config import  URL_DATAQUERIES
from .._common.const import *
from .._core._req_builder import _dataquery, _taskquery
from .._utils import _validate_args, _req_call, _authentication


def binary_operation(func):
    @wraps(func)
    def wrapper(obj, other):
        func(obj, other)
        ops = FUNCTIONS.get(func.__name__)
        s_op = ops.get('op')

        if other is None:
            raise TypeError(f'{s_op} missing 1 required positional argument')

        if isinstance(other, numbers.Real) or isinstance(other, str):
            other_node = __PrismValue(data=other)
        elif isinstance(other, _PrismComponent):
            other_node = other
        elif (obj._component_name == 'SecurityMaster') & isinstance(other, str):
            other_node =  __PrismValue(data=other)
        else:
            raise TypeError(f'unsupported operand type(s) for {s_op}: {type(obj)}, {type(other)}')

        component_name = func.__name__
        component_args = {}
        ret = _functioncomponent_builder(component_name, component_args, obj, other_node)
        return ret

    return wrapper


def operation(func):
    @wraps(func)
    def wrapper(obj, *args, **kwargs):
        func(obj, *args, **kwargs)
        vars = func.__code__.co_varnames[1:]
        component_name = func.__name__
        component_args = dict(zip(vars[: len(args)], args))
        component_args.update(dict(kwargs))
        ret = _functioncomponent_builder(component_name, component_args, obj)
        return ret

    return wrapper


def n_period_operation(func):
    @wraps(func)
    def wrapper(obj, n):
        if not issubclass(type(n), int):
            raise TypeError(f'Type of n is {type(n)} and not {int}')
        if func.__name__ == 'n_periods_shift':
            if n < 1:
                raise Exception("n must be a positive integer")
        return func(obj, n)

    return wrapper


def cross_sectional_operation(func):
    return operation(func)


def group_operation(func):
    @wraps(func)
    def wrapper(obj, other, *args, **kwargs):
        func(obj, other, *args, **kwargs)
        if other is None:
            raise Exception('Operation needs two inputs.')
        vars = func.__code__.co_varnames[2:]
        component_name = func.__name__
        component_args = dict(zip(vars[: len(args)], args))
        component_args.update(dict(kwargs))
        ret = _functioncomponent_builder('functioncomponent', component_name, component_args, obj, other)
        return ret

    return wrapper


def _functioncomponent_builder(component_name, component_args, *args):
    if len(args) < 1:
        raise Exception("need children (can be empty)")
    query = {
        'component_type': PrismComponentType.FUNCTION_COMPONENT,
        'component_name': component_name,
        'component_args': component_args,
        'children': [n._query for n in args],
    }
    return _PrismComponent(**query)


class _PrismComponent(_AbstractPrismComponent):
    """
    Args:
        query(dict): incl. component_type, component_name, component_args, children
    """

    def __init__(self, **kwargs):
        super().__init__(**kwargs)

    # simple operations
    @binary_operation
    def __add__(self, other):
        pass

    @binary_operation
    def __radd__(self, other):
        pass

    @binary_operation
    def __sub__(self, other):
        pass

    @binary_operation
    def __rsub__(self, other):
        pass

    @binary_operation
    def __mul__(self, other):
        pass

    @binary_operation
    def __rmul__(self, other):
        pass

    @binary_operation
    def __truediv__(self, other):
        pass

    @binary_operation
    def __rtruediv__(self, other):
        pass

    @binary_operation
    def __mod__(self, other):
        pass

    @binary_operation
    def __rmod__(self, other):
        pass

    @binary_operation
    def __pow__(self, other):
        pass

    @binary_operation
    def __rpow__(self, other):
        pass

    # logical operations
    @binary_operation
    def __eq__(self, other):
        pass

    @binary_operation
    def __ne__(self, other):
        pass

    @binary_operation
    def __gt__(self, other):
        pass

    @binary_operation
    def __ge__(self, other):
        pass

    @binary_operation
    def __lt__(self, other):
        pass

    @binary_operation
    def __le__(self, other):
        pass

    @binary_operation
    def __and__(self, other):
        pass

    @binary_operation
    def __or__(self, other):
        pass

    @binary_operation
    def __xor__(self, other):
        pass

    # other operations
    @operation
    def __invert__(self):
        pass

    @_validate_args
    @operation
    def resample(self, frequency: str, lookback: int = None, beyond: bool = True):
        pass

    @operation
    def round(self, n: int):
        pass

    @operation
    def trunc(self):
        pass

    @operation
    def floor(self):
        pass

    @operation
    def ceil(self):
        pass

    @operation
    def tanh(self):
        pass

    @operation
    def cosh(self):
        pass

    @operation
    def sinh(self):
        pass

    @operation
    def arctan(self):
        pass

    @operation
    def arccos(self):
        pass

    @operation
    def arcsin(self):
        pass

    @operation
    def tan(self):
        pass

    @operation
    def cos(self):
        pass

    @operation
    def sin(self):
        pass

    @operation
    def sqrt(self):
        pass

    @_validate_args
    @operation
    def log(self, base: numbers.Real = math.e):
        pass

    @operation
    def ln(self):
        pass

    @operation
    def exp(self):
        pass

    @operation
    def __abs__(self):
        pass

    # n-period operations
    @n_period_operation
    @operation
    def n_periods_pct_change(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_shift(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_diff(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_max(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_min(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_mean(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_ewma(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_median(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_sum(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_stderror(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_std(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_z_score(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_skew(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_kurt(self, n: int):
        pass

    # cross-sectional operations
    @_validate_args
    @cross_sectional_operation
    def cross_sectional_rank(self, rank_method: str = 'standard', ascending: bool = True):
        pass

    @_validate_args
    @cross_sectional_operation
    def cross_sectional_percentile(self, rank_method: str = 'standard', ascending: bool = True):
        pass

    @_validate_args
    @cross_sectional_operation
    def cross_sectional_quantile(
        self,
        bins: int,
        rank_method: str = 'standard',
        ascending: bool = True,
        right: bool = True,
    ):
        pass

    @cross_sectional_operation
    def cross_sectional_z_score(self):
        pass

    @cross_sectional_operation
    def cross_sectional_demean(self):
        pass

    @cross_sectional_operation
    def cross_sectional_sum(self):
        pass

    @cross_sectional_operation
    def cross_sectional_max(self):
        pass

    @cross_sectional_operation
    def cross_sectional_min(self):
        pass

    @cross_sectional_operation
    def cross_sectional_mean(self):
        pass

    @cross_sectional_operation
    def cross_sectional_std(self):
        pass

    @cross_sectional_operation
    def cross_sectional_median(self):
        pass

    @cross_sectional_operation
    def cross_sectional_count(self):
        pass

    # group operations
    @group_operation
    def group_mean(self, group):
        pass

    @group_operation
    def group_std(self, group):
        pass

    @group_operation
    def group_min(self, group):
        pass

    @group_operation
    def group_max(self, group):
        pass

    @group_operation
    def group_sum(self, group):
        pass

    @group_operation
    def group_count(self, group):
        pass

    @group_operation
    def group_median(self, group):
        pass

    @group_operation
    def group_demean(self, group):
        pass

    @group_operation
    def group_z_score(self, group):
        pass

    @_validate_args
    @group_operation
    def group_rank(self, group, rank_method: str = "standard", ascending: bool = True):
        pass

    @_validate_args
    @group_operation
    def group_percentile(self, group, rank_method: str = "standard", ascending: bool = True):
        pass

    @_validate_args
    @group_operation
    def group_quantile(
        self,
        group,
        bins: int,
        rank_method: str = "standard",
        ascending: bool = True,
        right: bool = True,
    ):
        pass

    # map operation
    @_validate_args
    def map(self, args: dict):
        component_args = {}
        children = [self._query]

        for k, v in args.items():
            if isinstance(v, _PrismComponent):
                nodeid = str(uuid.uuid4())
                query = copy.deepcopy(v._query)
                query['nodeid'] = nodeid
                component_args[k] = query
                children.append(query)
            else:
                component_args[k] = {
                    'component_type': PrismComponentType.DATA_COMPONENT,
                    'component_name': OtherDataComponentType.PRISMVALUE,
                    'component_args': {'data': v},
                    'children': [],
                }

        query = {
            'component_type': PrismComponentType.FUNCTION_COMPONENT,
            'component_name': 'map',
            'component_args': component_args,
            'children': children,
        }

        ret = _PrismComponent(**query)
        return ret

    @_validate_args
    @_req_call(_dataquery)
    def get_data(
        self,
        universe,
        startdate: str = None,
        enddate: str = None,
        shownid: list = None,
    ) -> pd.DataFrame:
        pass

    @_validate_args
    def save(self, name: str):
        return _dataquery.save_dataquery(self, name)


class _PrismDataComponent(_PrismComponent, ABC):
    """
    Abstract class for base nodes.
    Enforces _component_name as default class attribute.
    Args:
        kwargs: dict of component_args
    """

    _component_type = PrismComponentType.DATA_COMPONENT

    def __init__(self, **kwargs):
        component_args = dict(kwargs)
        query = {
            'component_type': self._component_type,
            'component_name': self._component_name,
            'component_args': component_args,
            'children': [],
            'nodeid': str(uuid.uuid4())
        }
        val_res = requests.post(url=URL_DATAQUERIES + '/validate', json=query, headers=_authentication())
        if val_res.status_code >= 400:
            if val_res.status_code == 401:
                raise ValueError(f'\033[91mNot Authenticated\033[0m: Please Login First', True, "Custom") from None
            else:
                try:
                    err_msg = val_res.json()['message']
                except:
                    err_msg = val_res.content
                raise ValueError(f'\033[91mValue Error\033[0m: {err_msg}', True, 'Custom') from None
        super().__init__(**query)

    @property
    @classmethod
    @abstractmethod
    def _component_name():
        return NotImplementedError

    def __setattr__(self, name, value):
        if name == '_component_name':
            raise AttributeError("Can't modify {}".format(name))

        super().__setattr__(name, value)


class _PrismTaskComponent(_AbstractPrismComponent, ABC):
    _component_type = PrismComponentType.TASK_COMPONENT

    def __init__(self, **kwargs):
        component_args = dict(kwargs)
        query = {
            'component_type': self._component_type,
            'component_name': self._component_name,
            'component_args': component_args,
            'children': [],
        }
        super().__init__(**query)

    def run(self, *args, **kwargs):
        raise NotImplementedError

    @_validate_args
    def save(self, name: str) -> None:
        return _taskquery.save_taskquery(self, name)


class __PrismValue(_PrismComponent):
    _component_type = PrismComponentType.DATA_COMPONENT
    _component_name = OtherDataComponentType.PRISMVALUE

    def __init__(self, **kwargs):
        component_args = dict(kwargs)
        query = {
            'component_type': self._component_type,
            'component_name': self._component_name,
            'component_args': component_args,
            'children': [],
        }
        super().__init__(**query)

==> prismstudio-1.0.3-py3-none-any.whl: prism/_prismcomponent/prismcomponent.py <==
import copy
import numbers
import math
import inspect
import requests
import uuid
from abc import ABC, abstractmethod
from functools import wraps
from typing import Union

import pandas as pd

from prism._utils.exceptions import PrismAuthError, PrismResponseError, PrismTypeError, PrismValueError

from .._prismcomponent.abstract_prismcomponent import _AbstractPrismComponent
from .._common.config import URL_DATAQUERIES
from .._common.const import *
from .._core._req_builder import _dataquery, _taskquery
from .._utils import _validate_args, _req_call, _authentication, post


def binary_operation(func):
    @wraps(func)
    def wrapper(obj, other):
        func(obj, other)
        ops = FUNCTIONS.get(func.__name__)
        s_op = ops.get("op")

        if other is None:
            raise PrismTypeError(f"{s_op} missing 1 required positional argument")

        if isinstance(other, numbers.Real) or isinstance(other, str):
            other_node = __PrismValue(data=other)
        elif isinstance(other, _PrismComponent):
            other_node = other
        elif (obj._component_name == "SecurityMaster") & isinstance(other, str):
            other_node = __PrismValue(data=other)
        else:
            raise PrismTypeError(f"unsupported operand type(s) for {s_op}: {type(obj)}, {type(other)}")

        component_name = func.__name__
        component_args = {}
        ret = _functioncomponent_builder(component_name, component_args, obj, other_node)
        return ret

    return wrapper

def get_default_args(func):
    signature = inspect.signature(func)
    return {
        k: v.default
        for k, v in signature.parameters.items()
        if v.default is not inspect.Parameter.empty
    }

def operation(func):
    @wraps(func)
    def wrapper(obj, *args, **kwargs):
        func(obj, *args, **kwargs)
        vars = func.__code__.co_varnames[1:]
        component_name = func.__name__
        component_args = dict(zip(vars[: len(args)], args))
        default_args = get_default_args(func)
        component_args.update(dict(kwargs))
        component_args.update(default_args)
        ret = _functioncomponent_builder(component_name, component_args, obj)
        return ret

    return wrapper


def n_period_operation(func):
    @wraps(func)
    def wrapper(obj, n):
        if not issubclass(type(n), int):
            raise PrismTypeError(f"Type of n is {type(n)} and not {int}")
        if func.__name__ == "n_periods_shift":
            if n < 1:
                raise PrismValueError("n must be a positive integer")
        return func(obj, n)

    return wrapper


def cross_sectional_operation(func):
    return operation(func)


def group_operation(func):
    @wraps(func)
    def wrapper(obj, other, *args, **kwargs):
        func(obj, other, *args, **kwargs)
        if other is None:
            raise PrismTypeError("Operation needs two inputs.")
        vars = func.__code__.co_varnames[2:]
        component_name = func.__name__
        component_args = dict(zip(vars[: len(args)], args))
        component_args.update(dict(kwargs))
        ret = _functioncomponent_builder(component_name, component_args, obj, other)
        return ret

    return wrapper


def _functioncomponent_builder(component_name, component_args, *args):
    if len(args) < 1:
        raise PrismValueError("need children (can be empty)")
    query = {
        "component_type": PrismComponentType.FUNCTION_COMPONENT,
        "component_name": component_name,
        "component_args": component_args,
        "children": [n._query for n in args],
        "nodeid": str(uuid.uuid4()),
    }
    return _PrismComponent(**query)


class _PrismComponent(_AbstractPrismComponent):
    """
    Args:
        query(dict): incl. component_type, component_name, component_args, children
    """

    def __init__(self, **kwargs):
        super().__init__(**kwargs)

    # simple operations
    @binary_operation
    def __add__(self, other):
        pass

    @binary_operation
    def __radd__(self, other):
        pass

    @binary_operation
    def __sub__(self, other):
        pass

    @binary_operation
    def __rsub__(self, other):
        pass

    @binary_operation
    def __mul__(self, other):
        pass

    @binary_operation
    def __rmul__(self, other):
        pass

    @binary_operation
    def __truediv__(self, other):
        pass

    @binary_operation
    def __rtruediv__(self, other):
        pass

    @binary_operation
    def __mod__(self, other):
        pass

    @binary_operation
    def __rmod__(self, other):
        pass

    @binary_operation
    def __pow__(self, other):
        pass

    @binary_operation
    def __rpow__(self, other):
        pass

    # logical operations
    @binary_operation
    def __eq__(self, other):
        pass

    @binary_operation
    def __ne__(self, other):
        pass

    @binary_operation
    def __gt__(self, other):
        pass

    @binary_operation
    def __ge__(self, other):
        pass

    @binary_operation
    def __lt__(self, other):
        pass

    @binary_operation
    def __le__(self, other):
        pass

    @binary_operation
    def __and__(self, other):
        pass

    @binary_operation
    def __or__(self, other):
        pass

    @binary_operation
    def __xor__(self, other):
        pass

    # other operations
    @operation
    def __invert__(self):
        pass

    @_validate_args
    @operation
    def resample(self, frequency: str, lookback: int = None, beyond: bool = True):
        pass

    @operation
    def round(self, decimals: int = 0):
        pass

    @operation
    def trunc(self):
        pass

    @operation
    def floor(self):
        pass

    @operation
    def ceil(self):
        pass

    @operation
    def tanh(self):
        pass

    @operation
    def cosh(self):
        pass

    @operation
    def sinh(self):
        pass

    @operation
    def arctan(self):
        pass

    @operation
    def arccos(self):
        pass

    @operation
    def arcsin(self):
        pass

    @operation
    def tan(self):
        pass

    @operation
    def cos(self):
        pass

    @operation
    def sin(self):
        pass

    @operation
    def sqrt(self):
        pass

    @_validate_args
    @operation
    def log_n(self, n: numbers.Real = 10):
        pass

    @operation
    def ln(self):
        pass

    @operation
    def exp(self):
        pass

    @operation
    def __abs__(self):
        pass

    # n-period operations
    @n_period_operation
    @operation
    def n_periods_pct_change(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_shift(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_diff(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_max(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_min(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_mean(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_ewma(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_median(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_sum(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_sem(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_std(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_z_score(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_skew(self, n: int):
        pass

    @n_period_operation
    @operation
    def n_periods_kurt(self, n: int):
        pass

    # cross-sectional operations
    @_validate_args
    @cross_sectional_operation
    def cross_sectional_rank(self, rank_method: str = "standard", ascending: bool = True):
        pass

    @_validate_args
    @cross_sectional_operation
    def cross_sectional_percentile(self, rank_method: str = "standard", ascending: bool = True):
        pass

    @_validate_args
    @cross_sectional_operation
    def cross_sectional_quantile(
        self,
        bins: int,
        rank_method: str = "standard",
        ascending: bool = True,
        right: bool = True,
    ):
        pass

    @cross_sectional_operation
    def cross_sectional_z_score(self):
        pass

    @cross_sectional_operation
    def cross_sectional_demean(self):
        pass

    @cross_sectional_operation
    def cross_sectional_sum(self):
        pass

    @cross_sectional_operation
    def cross_sectional_max(self):
        pass

    @cross_sectional_operation
    def cross_sectional_min(self):
        pass

    @cross_sectional_operation
    def cross_sectional_mean(self):
        pass

    @cross_sectional_operation
    def cross_sectional_std(self):
        pass

    @cross_sectional_operation
    def cross_sectional_median(self):
        pass

    @cross_sectional_operation
    def cross_sectional_count(self):
        pass

    @cross_sectional_operation
    def cross_sectional_sem(self):
        pass

    @cross_sectional_operation
    def cross_sectional_mad(self):
        pass

    # group operations
    @group_operation
    def group_mean(self, group):
        pass

    @group_operation
    def group_std(self, group):
        pass

    @group_operation
    def group_min(self, group):
        pass

    @group_operation
    def group_max(self, group):
        pass

    @group_operation
    def group_sum(self, group):
        pass

    @group_operation
    def group_count(self, group):
        pass

    @group_operation
    def group_median(self, group):
        pass

    @group_operation
    def group_demean(self, group):
        pass

    @group_operation
    def group_z_score(self, group):
        pass

    @_validate_args
    @group_operation
    def group_rank(self, group, rank_method: str = "standard", ascending: bool = True):
        pass

    @_validate_args
    @group_operation
    def group_percentile(self, group, rank_method: str = "standard", ascending: bool = True):
        pass

    @_validate_args
    @group_operation
    def group_quantile(
        self,
        group,
        bins: int,
        rank_method: str = "standard",
        ascending: bool = True,
        right: bool = True,
    ):
        pass

    @group_operation
    def group_sem(self, group):
        pass

    @group_operation
    def group_mad(self, group):
        pass

    # map operation
    @_validate_args
    def map(self, args: dict):
        component_args = {}
        children = [self._query]

        for k, v in args.items():
            if isinstance(v, _PrismComponent):
                # nodeid = str(uuid.uuid4())
                query = copy.deepcopy(v._query)
                # query['nodeid'] = nodeid
                component_args[k] = query
                children.append(query)
            else:
                component_args[k] = {
                    "component_type": PrismComponentType.DATA_COMPONENT,
                    "component_name": OtherDataComponentType.PRISMVALUE,
                    "component_args": {"data": v},
                    "children": [],
                }

        query = {
            "component_type": PrismComponentType.FUNCTION_COMPONENT,
            "component_name": "map",
            "component_args": component_args,
            "children": children,
        }

        ret = _PrismComponent(**query)
        return ret

    @_validate_args
    @_req_call(_dataquery)
    def get_data(
        self,
        universe: Union[str, int],
        startdate: str = None,
        enddate: str = None,
        shownid: list = None,
        name: list = None,
    ) -> pd.DataFrame:
        pass

    @_validate_args
    @_req_call(_dataquery)
    def view_data(
        self,
        universe,
        startdate: str = None,
        enddate: str = None,
        shownid: list = None,
        name: list = None,
    ) -> pd.DataFrame:
        pass

    @_validate_args
    def save(self, name: str):
        return _dataquery.save_dataquery(self, name)

    @_validate_args
    def extract(self, return_code=False):
        return _dataquery.extract_dataquery(self, return_code)


class _PrismDataComponent(_PrismComponent, ABC):
    """
    Abstract class for base nodes.
    Enforces _component_name as default class attribute.
    Args:
        kwargs: dict of component_args
    """

    _component_type = PrismComponentType.DATA_COMPONENT

    def __init__(self, **kwargs):
        component_args = dict(kwargs)
        query = {
            "component_type": self._component_type,
            "component_name": self._component_name,
            "component_args": component_args,
            "children": [],
            "nodeid": str(uuid.uuid4()),
        }
        val_res = requests.post(url=URL_DATAQUERIES + "/validate", json=query, headers=_authentication())
        if val_res.status_code >= 400:
            if val_res.status_code == 401:
                raise PrismAuthError(f"Please Login First")
            else:
                try:
                    err_msg = val_res.json()["message"]
                except:
                    err_msg = val_res.content
                raise PrismResponseError(err_msg)
        query = val_res.json()["rescontent"]["data"]
        query.pop("query_name")
        super().__init__(**query)

    @property
    @classmethod
    @abstractmethod
    def _component_name():
        raise NotImplementedError()

    def __setattr__(self, name, value):
        if name == "_component_name":
            raise AttributeError("Can't modify {}".format(name))

        super().__setattr__(name, value)


class _PrismTaskComponent(_AbstractPrismComponent, ABC):
    _component_type = PrismComponentType.TASK_COMPONENT

    def __init__(self, **kwargs):
        component_args = dict(kwargs)
        query = {
            "component_type": self._component_type,
            "component_name": self._component_name,
            "component_args": component_args,
            "children": [],
        }
        super().__init__(**query)

    def run(self, *args, **kwargs):
        raise NotImplementedError()

    @_validate_args
    def save(self, name: str) -> None:
        return _taskquery.save_taskquery(self, name)

    @_validate_args
    def extract(self, return_code=False):
        return _taskquery.extract_taskquery(self, return_code)


class __PrismValue(_PrismComponent):
    _component_type = PrismComponentType.DATA_COMPONENT
    _component_name = OtherDataComponentType.PRISMVALUE

    def __init__(self, **kwargs):
        component_args = dict(kwargs)
        query = {
            "component_type": self._component_type,
            "component_name": self._component_name,
            "component_args": component_args,
            "children": [],
        }
        super().__init__(**query)
